﻿using BrushUpTeacherValidatorUnitTest;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BrushUpTeacherValidatorUnitTestTests
{
    [TestClass]
    public class StudentTests
    {
        Student student = new Student { Id = 1, Name = "Ib", Semester = 1 };
        Student studentNameNull = new Student { Id = 2, Name = null, Semester = 1 };
        Student studentNameToShort = new Student { Id = 3, Name = "", Semester = 1 };
        Student studentSemesterToLow = new Student { Id = 1, Name = "Ib", Semester = 0 };
        Student studentSemesterToHigh = new Student { Id = 1, Name = "Ib", Semester = 9 };


        [TestMethod]
        public void ToStringTest()
        {
            string str = student.ToString();
            Assert.AreEqual("{Id=1, Name=Ib, Semester=1}", str);
        }

        [TestMethod]
        public void ValidateNameTest()
        {
            student.ValidateName();
            Assert.ThrowsException<ArgumentNullException>(() => studentNameNull.ValidateName());
            Assert.ThrowsException<ArgumentException>(() => studentNameToShort.ValidateName());
        }

        [TestMethod()]
        [DataRow(1)]
        [DataRow(2)]
        [DataRow(7)]
        [DataRow(8)]
        public void ValidateSemesterTest(int semester)
        {
            student.Semester = semester;
            student.ValidateSemester();
        }

        [TestMethod]
        public void ValidateSemesterOutOfRangeTest()
        {
            Assert.ThrowsException<ArgumentOutOfRangeException>(() => studentSemesterToLow.ValidateSemester());
            Assert.ThrowsException<ArgumentOutOfRangeException>(() => studentSemesterToHigh.ValidateSemester());
        }


        [TestMethod()]
        public void ValidateTest()
        {
            student.Validate();
            Assert.ThrowsException<ArgumentNullException>(() => studentNameNull.Validate());
            Assert.ThrowsException<ArgumentException>(() => studentNameToShort.Validate());
            Assert.ThrowsException<ArgumentOutOfRangeException>(() => studentSemesterToLow.Validate());
            Assert.ThrowsException<ArgumentOutOfRangeException>(() => studentSemesterToHigh.Validate());
        }
    }
}
