using RefactoredBrushUp;
using static RefactoredBrushUp.Person;

namespace RefactoredBrushUpTests
{
    [TestClass]
    public class PersonTests
    {
        //Bemrk hvis class Person er abstract kan der ikke laves instancer af klassen og dermed heller ingen unittest!!
        private IPerson person = new Person {Id = 1, Name = "Henrik Hltzer", Gender = GenderType.Male };
        private IPerson personGenderNoValue = new Person {Id = 2, Name = "Henrik Hltzer" };
        private IPerson personNameNull = new Person {Id = 3, Name = null, Gender = GenderType.Male };
        private IPerson personNameToShort = new Person {Id = 4, Name = "", Gender = GenderType.Male };
        private IPerson personEquals = new Person { Id = 1, Name = "Henrik Hltzer", Gender = GenderType.Male };

        [TestMethod]
        public void ToStringTest()
        {
            string str = person.ToString();
            Assert.AreEqual("Id=1, Name=Henrik Hltzer, Gender=Male", str);
        }

        [TestMethod]
        public void ValidateNameTest()
        {
            person.ValidateName();
            Assert.ThrowsException<ArgumentNullException>(() => personNameNull.ValidateName());
            Assert.ThrowsException<ArgumentException>(() => personNameToShort.ValidateName());
        }

        [TestMethod]
        public void ValidateGenderTest()
        {
            person.ValidateGender();
            Assert.ThrowsException<ArgumentException>(() => personGenderNoValue.ValidateGender());
        }

        //Bemrk, da Eaquals og Hashcode metoderne er genereret automatisk er det normalt ikke ndvendigt at teste dem
        [TestMethod]
        public void ValidateEqualsAndHashCodeTest()
        {
            Assert.IsTrue(personEquals.Equals(person));
            Assert.IsTrue(personEquals.GetHashCode() == person.GetHashCode()); 
        }


    }
}